#!/bin/bash
# Skriptname:	/usr/sbin/DEBIANPaketRepository
# 


# ######################################################################### #
function Fnkt_Hilfe() {

	# ##################################################################### #
	echo "";
	echo "Verwendung des Skriptes:";
	echo "    $(basename -- $0) <Schalter> <Repository-Verzeichnis> [<DEBIAN-Paket>|<Paketname>]";
	echo ""
	echo "Das sind die möglichen Schalter:
    -i: Importieren eines DEBIAN-Paketes in das Repository
            Zusätzlich wird folgender Parameter benötigt:
            <DEBIAN-Paket>: DEBIAN-Paket, welches importiert werden soll

    -e: Entfernen eines Paketes aus dem Repository
            Zusätzlich wird folgender Parameter benötigt:
            <Paketname>   :	Paketname des Paketes, welches entfernt werden soll

    -l: Anzeigen aller importierten DEBIAN-Pakete eines Repository
            Keine zusätzlichen Parameter notwendig
			
    -h: Anzeigen der Hilfe (Standardauswahl)
    " && return 0;

};
# ######################################################################### #

# ######################################################################### #
function Fnkt_Importieren() {
	local Var_RepositoryVerzeichnis="${1}";
	local Var_DebianPaket="${2}";

	# --------------------------------------------------------------------- #
	# Parameterabfrage
	if [ ${#Var_DebianPaket} -eq 0 ]; then
		echo "FEHLER: Es wurde keine Datei zum Importieren angegeben.";
		Fnkt_Hilfe;
		exit 0;
	elif [ ! -s "${Var_DebianPaket}" ]; then
		echo "FEHLER: Die angebene Datei zum Importieren existiert nicht.";
		return 255;
	fi;

	# --------------------------------------------------------------------- #
	# Importieren der Datei
	reprepro -S main -P 5 -b "${Var_RepositoryVerzeichnis}" includedeb repo "${Var_DebianPaket}";
	return $?

};
# ######################################################################### #

# ######################################################################### #
function Fnkt_Entfernen() {
	local Var_RepositoryVerzeichnis="${1}";
	local Var_Paketname="${2}";

	# --------------------------------------------------------------------- #
	# Paketpruefung
	if ! Fnkt_Auflisten "${Var_RepositoryVerzeichnis}" | grep -q "${Var_Paketname}"; then
		echo "FEHLER: Das Paket '${Var_Paketname}' befindet sich nicht im Repository.";
		return 254;
	fi;

	# --------------------------------------------------------------------- #
	# Entfernen des Paketes
	reprepro -b "${Var_RepositoryVerzeichnis}" remove repo "${Var_Paketname}";
	return $?

};
# ######################################################################### #

# ######################################################################### #
function Fnkt_Auflisten() {
	local Var_RepositoryVerzeichnis="${1}";

	# --------------------------------------------------------------------- #
	# Auflisten der Pakete
	reprepro -b "${Var_RepositoryVerzeichnis}" list repo;
	return $?

};
# ######################################################################### #

# ######################################################################### #
# Parameterabfrage
if [ ${#1} -eq 0 ]; then
	echo "FEHLER: Es wurde kein Schalter übergeben.";
	Fnkt_Hilfe;
	Var_Fehler=$?
else
	if [ "${1}" == "-h" ]; then
		Fnkt_Hilfe;
		exit 0;
	else
		if [ ${#2} -eq 0 ]; then
			echo "FEHLER: Es wurde kein Repository-Verzeichnis angegeben.";
			Fnkt_Hilfe;
			exit 0;
		else
			if [ ! -d "${2}" ]; then
				echo "FEHLER: Repository-Verzeichnis '${2}' existiert nicht";
				exit 255;
			fi;
		fi;
	fi;
fi;


# ######################################################################### #
# Auswahl
case ${1} in
	"-i")
		Fnkt_Importieren "${2}" "${3}";
		Var_Fehler=$?
		;;
	
	"-e")
		Fnkt_Entfernen "${2}" "${3}";
		Var_Fehler=$?
		;;

	"-l")
		Fnkt_Auflisten "${2}";
		Var_Fehler=$?
		;;
	
	"-h")
		Fnkt_Hilfe;
		Var_Fehler=$?
		;;

	 *)
		echo ""
		Var_Fehler=0;

# Ende
esac;

# ######################################################################### #
# Fehlerauswertung
if [ ${Var_Fehler} -ne 0 ]; then
	echo "Das Skript wurde mit dem Fehler '${Var_Fehler}' beendet.";
fi;

# ######################################################################### #
# Skriptende

# ######################################################################### #
# ######################################################################### #
# ######################################################################### #

